<?php

namespace Drupal\exitpopup\Form;

/**
* @file
* Contains Drupal\exitpopup\Form\ExitPopUp.
*/

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use \Drupal\user\Entity\Role;

/**
 * Class ExitPopUp.
 */
class ExitPopUp extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'exitpopup.settings',
    ];
  }

  /**
   * Get form id.
   */
  public function getFormId() {
    return 'exitpopup_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('exitpopup.settings');

    $form['epu_html'] = array(
      '#type' => 'text_format',
      '#format' => 'restricted_html',
      '#base_type' => 'textarea',
      '#rows' => 20,
      '#title' => ' HTML Template',
      '#description' => 'The HTML code to be placed within the popup. HTML can be added through this function or on the page itself within a element.',
      '#default_value' => $config->get('epu_html.value'),
    );

    $form['epu_css'] = array(
      '#type' => 'text_format',
      '#format' => 'restricted_html',
      '#rows' => 20,
      '#title' => 'Custom CSS',
      '#description' => 'write custom css for the above html code ',
      '#default_value' => $config->get('epu_css.value'),
    );

    $form['epu_delay'] = array(
      '#type' => 'number',
      '#title' => ' Delay on Display POP UP',
      '#description' => 'The time, in seconds, until the popup activates and begins watching for exit intent. If showOnDelay is set to true, this will be the time until the popup shows. ',
      '#default_value' => $config->get('epu_delay'),
    );

    $form['epu_cookie_exp'] = array(
      '#type' => 'number',
      '#title' => 'Cookie Expire Time (in Days)',
      '#description' => 'The number of days to set the cookie for. A cookie is used to track if the popup has already been shown to a specific visitor. If the popup has been shown, it will not show again until the cookie expires. A value of 0 will always show the popup. ',
      '#default_value' => $config->get('epu_cookie_exp'),
    );

    $form['epu_width'] = array(
      '#type' => 'number',
      '#title' => ' Width For the POP UP',
      '#description' => 'The width of the popup. This can be overridden by adding your own CSS for the #bio_ep element. ',
      '#default_value' => $config->get('epu_width'),
    );

    $form['epu_height'] = array(
      '#type' => 'number',
      '#title' => ' Height For the POP UP',
      '#description' => 'The width of the popup. This can be overridden by adding your own CSS for the #bio_ep element. ',
      '#default_value' => $config->get('epu_height'),
    );

    $defaultRoles = $config->get('roles');
    $roles = Role::loadMultiple();
    $options = [];
    foreach ($roles as $role) {
      $options[$role->id()] = $role->label();
    }

    $form['roles'] = [
      '#type' => 'checkboxes',
      '#title' => t('Select roles to show exit popup'),
      '#options' => $options,
      '#default_value' => isset($defaultRoles) ? $defaultRoles : FALSE,
    ];

    $form['cache'] = [
      '#cache' => [
        'max-age' => 0,
      ],
    ];


    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    // Get the config object.
    $config = $this->config('exitpopup.settings');

    $epu_html = $form_state->getValue('epu_html')['value'];
    $epu_css = $form_state->getValue('epu_css')['value'];
    $epu_delay = $form_state->getValue('epu_delay');
    $epu_width = $form_state->getValue('epu_width');
    $epu_height = $form_state->getValue('epu_height');
    $epu_cookie_exp = $form_state->getValue('epu_cookie_exp');
    $roles = $form_state->getValue('roles');

    // Set the values the user submitted in the form.
    $config->set('epu_html.value', $epu_html)
      ->set('epu_css.value', $epu_css)
      ->set('epu_delay', $epu_delay)
      ->set('epu_width', $epu_width)
      ->set('epu_height', $epu_height)
      ->set('epu_cookie_exp', $epu_cookie_exp)
      ->set('roles', $roles)
      ->save();
  }

}
